"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
var LinesAction;
(function (LinesAction) {
    LinesAction[LinesAction["expandSql"] = 0] = "expandSql";
    LinesAction[LinesAction["prettySql"] = 1] = "prettySql";
    LinesAction[LinesAction["sortNormal"] = 2] = "sortNormal";
    LinesAction[LinesAction["unwrapSql"] = 3] = "unwrapSql";
    LinesAction[LinesAction["wrapSql"] = 4] = "wrapSql";
})(LinesAction || (LinesAction = {}));
function removeBlanks(lines) {
    for (let i = 0; i < lines.length; ++i) {
        if (lines[i].trim() === '') {
            lines.splice(i, 1);
            i--;
        }
    }
}
function getLines(textEditor, startLine, endLine) {
    let results = [];
    for (let i = startLine; i <= endLine; i++) {
        results.push(textEditor.document.lineAt(i).text);
    }
    return results;
}
function expandSqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = lines[i].replace(' from', '\r\n from').replace(' where', '\r\n where').replace(' and', '\r\n and').replace(' join', '\r\n join').replace(' left join', '\r\n left join');
    }
}
function prettySqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = lines[i].replace(' from ', ' FROM ').replace(' where ', ' WHERE').replace(' and ', ' AND ').replace(' join ', ' JOIN ').replace(' left join ', ' LEFT JOIN ');
    }
}
function makeSorter(algorithm) {
    return function (lines) {
        return lines.sort(algorithm);
    };
}
function sortNormalLogic(lines) {
    var transformers = [];
    transformers.push(makeSorter());
    removeBlanks(lines);
    lines = transformers.reduce((currentLines, transform) => transform(currentLines), lines);
}
function unwrapSqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = "'" + lines[i].replace('sql = "', '').replace('sql = sql & "', '').replace('" & ', '$').replace(' & "', '$').replace('"', '').trim();
    }
}
function wrapSqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = 'sql = sql & " ' + lines[i] + ' "';
    }
}
function returnLines(textEditor, startLine, endLine, lines) {
    return textEditor.edit(editBuilder => {
        const range = new vscode.Range(startLine, 0, endLine, textEditor.document.lineAt(endLine).text.length);
        editBuilder.replace(range, lines.join('\n'));
    });
}
function linesFunction(linesAction) {
    const textEditor = vscode.window.activeTextEditor;
    if (!textEditor) {
        return undefined;
    }
    var startLine = 0;
    var endLine = textEditor.document.lineCount - 1;
    const selection = textEditor.selection;
    if (!selection.isEmpty) {
        startLine = selection.start.line;
        endLine = selection.end.line;
    }
    let lines = getLines(textEditor, startLine, endLine);
    switch (linesAction) {
        case LinesAction.expandSql: {
            expandSqlLogic(lines);
            break;
        }
        case LinesAction.prettySql: {
            prettySqlLogic(lines);
            break;
        }
        case LinesAction.sortNormal: {
            sortNormalLogic(lines);
            break;
        }
        case LinesAction.unwrapSql: {
            unwrapSqlLogic(lines);
            break;
        }
        case LinesAction.wrapSql: {
            wrapSqlLogic(lines);
            break;
        }
        default: {
            throw new Error();
        }
    }
    return returnLines(textEditor, startLine, endLine, lines);
}
exports.expandSql = () => linesFunction(LinesAction.expandSql);
exports.prettySql = () => linesFunction(LinesAction.prettySql);
exports.sortNormal = () => linesFunction(LinesAction.sortNormal);
exports.unwrapSql = () => linesFunction(LinesAction.unwrapSql);
exports.wrapSql = () => linesFunction(LinesAction.wrapSql);
//# sourceMappingURL=helper.js.map